@@ -19,9 +19,12 @@ public:
 public slots:
     void updateCoords();
     void processCoords(QString &data);
+    void readProximity();
+    void update();
 
 signals:
     void deviceOrientation(QString x, QString y, QString z);
+    void proximityState(QString state);
 };
 
 #endif // ATHREAD_H
