@@ -5,13 +5,6 @@ MotionWindow::MotionWindow(QWidget *parent) :
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    wd = new WeightDialog(this);
-    wd->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
-
     QWidget *widget = new QWidget();
     setCentralWidget(widget);
 
@@ -34,6 +27,11 @@ MotionWindow::MotionWindow(QWidget *parent) :
     createMenu();
 }
 
+void MotionWindow::sendClosed()
+{
+    emit closed();
+}
+
 void MotionWindow::load(QString exercise)
 {
     name = exercise;
@@ -46,6 +44,7 @@ void MotionWindow::load(QString exercise)
 void MotionWindow::buttonClicked()
 {
     QString strSec, strMin;
+
     if(button->text() == "Start")
     {
         button->setText("Stop");
@@ -59,6 +58,7 @@ void MotionWindow::buttonClicked()
         strSec.setNum(sec);
         strMin.setNum(min);
 
+        wd = new WeightDialog(this);
         wd->loadCardio(name, strMin, strSec);
         wd->show();
     }
@@ -87,32 +87,39 @@ void MotionWindow::closeEvent(QCloseEvent *event)
     tmr->stop();
 }
 
+void MotionWindow::showNewIngredient()
+{
+    niw = new NewIngredientWindow(this);
+    niw->load();
+    niw->show();
+}
+
 void MotionWindow::showHistory()
 {
+    hw = new HistoryWindow(this);
     hw->load();
     hw->show();
 }
 
-void MotionWindow::showNewIngredient()
-{
-    niw->load();
-    niw->show();
-}
 void MotionWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void MotionWindow::showNewExercise()
 {
-
+    nw = new NewExerciseWindow(this);
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
     nw->load();
     nw->show();
 }
 
 void MotionWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
