@@ -17,10 +17,13 @@ public:
     void load();
 
 signals:
-
+    void closed();
 private:
     XML *xml;
 
+
+    void closeEvent(QCloseEvent *event);
+
     QLineEdit *txtName;
     QLineEdit *txtMuscle;
     QTextEdit *txtHowTo;
